pub struct WindowState {
pub app: Arc<Mutex<App>>,
pub wgpu_window: Option<WgpuWindow>,
/* private fields */
}Fields
app: Arc<Mutex<App>>wgpu_window: Option<WgpuWindow>Trait Implementations
Sourceimpl AppHandler for WindowState
impl AppHandler for WindowState
Sourcefn cursor_moved(&mut self, physical_position: PhysicalPosition<u32>)
fn cursor_moved(&mut self, physical_position: PhysicalPosition<u32>)
opinionated, we want origin (0,0) in the lower left corner of the window
Sourcefn min_size(&self) -> (u16, u16)
fn min_size(&self) -> (u16, u16)
Returns the minimum window size (width, height) in pixels that the application requires. Read more
Sourcefn start_size(&self) -> (u16, u16)
fn start_size(&self) -> (u16, u16)
Returns the starting window size (width, height) in pixels when the application launches. Read more
fn cursor_should_be_visible(&self) -> bool
Sourcefn redraw(&mut self) -> bool
fn redraw(&mut self) -> bool
Called to trigger a redraw of the application’s content. Read more
Sourcefn lost_focus(&mut self)
fn lost_focus(&mut self)
Called when the application window loses focus. Read more
Sourcefn window_created(&mut self, window: Arc<Window>)
fn window_created(&mut self, window: Arc<Window>)
Called after the application window has been created and is ready to use. Read more
Sourcefn resized(&mut self, size: PhysicalSize<u32>)
fn resized(&mut self, size: PhysicalSize<u32>)
Called whenever the window is resized, providing the new physical size. Read more
Sourcefn keyboard_input(
&mut self,
element_state: ElementState,
physical_key: PhysicalKey,
)
fn keyboard_input( &mut self, element_state: ElementState, physical_key: PhysicalKey, )
Processes keyboard input events, such as key presses and releases. Read more
Sourcefn cursor_entered(&mut self)
fn cursor_entered(&mut self)
Called when the cursor enters the window. Read more
Sourcefn cursor_left(&mut self)
fn cursor_left(&mut self)
Called when the cursor leaves the window. Read more
Sourcefn mouse_input(&mut self, element_state: ElementState, button: MouseButton)
fn mouse_input(&mut self, element_state: ElementState, button: MouseButton)
Handles mouse button input events, such as presses and releases. Read more
Sourcefn mouse_wheel(&mut self, delta: MouseScrollDelta, touch_phase: TouchPhase)
fn mouse_wheel(&mut self, delta: MouseScrollDelta, touch_phase: TouchPhase)
Processes mouse wheel events, which indicate scrolling actions. Read more
fn pinch_gesture(&mut self, delta: f64, touch_phase: TouchPhase)
Sourcefn mouse_motion(&mut self, _delta: (f64, f64))
fn mouse_motion(&mut self, _delta: (f64, f64))
Handles mouse motion. the delta follows no standard, so it is up to the game to apply
a factor as it sees fit.
Sourcefn touch(&mut self, _touch: Touch)
fn touch(&mut self, _touch: Touch)
Handles touch input events, such as screen touches and gestures. Read more
Sourcefn scale_factor_changed(
&mut self,
_scale_factor: f64,
_inner_size_writer: InnerSizeWriter,
)
fn scale_factor_changed( &mut self, _scale_factor: f64, _inner_size_writer: InnerSizeWriter, )
Handles changes to the display scale factor, usually due to monitor DPI changes. Read more